# -*- coding: utf-8 -*-

"""
Maxi's Functions
~~~~~~~~~~~~~~~~

Contains all Functions

"""

from .better_input import better_input as BetterInput
from .better_print import better_print as BetterPrint
from .output import output as Output
from .terminal import Terminal as Terminal
